Crate placenew

Crate placenew 

Macros

place_boxed
place_boxed is a macro that creates a structure in-place from a structure initializer input
place_into
place_into! is a macro that generates code to construct a value in-place at a specified pointer location. you must wrap it in an unsafe block, as the macro does not or can not verify that the pointer is both properly aligned and contains enough space for the data to be constructed there/